Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1912)

Unified Diff: ui/ozone/public/ozone_platform.h

Issue 2795883002: Eliminate OnConnect usage (Closed)
Patch Set: . Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/ozone/platform/drm/ozone_platform_gbm.cc ('k') | ui/ozone/public/ozone_platform.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/ozone/public/ozone_platform.h
diff --git a/ui/ozone/public/ozone_platform.h b/ui/ozone/public/ozone_platform.h
index 97cab2cfebd51b060fd9870d7c7b618cebb65500..8a7eee595bfa03ebf1b1d97b95adcc39abf69560 100644
--- a/ui/ozone/public/ozone_platform.h
+++ b/ui/ozone/public/ozone_platform.h
@@ -24,8 +24,8 @@ class MessageFilter;
}
namespace service_manager {
+class BinderRegistry;
class Connector;
-class InterfaceRegistry;
}
namespace ui {
@@ -118,12 +118,12 @@ class OZONE_EXPORT OzonePlatform {
// Ozone platform implementations may also choose to expose mojo interfaces to
// internal functionality. Embedders wishing to take advantage of ozone mojo
// implementations must invoke AddInterfaces with a valid
// service_manager::InterfaceRegistry* pointer to export all Mojo interfaces
// defined within Ozone.
//
// A default do-nothing implementation is provided to permit platform
// implementations to opt out of implementing any Mojo interfaces.
- virtual void AddInterfaces(service_manager::InterfaceRegistry* registry);
+ virtual void AddInterfaces(service_manager::BinderRegistry* registry);
private:
virtual void InitializeUI(const InitParams& params) = 0;
« no previous file with comments | « ui/ozone/platform/drm/ozone_platform_gbm.cc ('k') | ui/ozone/public/ozone_platform.cc » ('j') | no next file with comments »
@@ -118,12 +118,12 @@ class OZONE_EXPORT OzonePlatform {
// internal functionality. Embedders wishing to take advantage of ozone mojo
// implementations must invoke AddInterfaces with a valid
- // service_manager::InterfaceRegistry* pointer to export all Mojo interfaces
+ // service_manager::BinderRegistry* pointer to export all Mojo interfaces
// defined within Ozone.
//

Powered by Google App Engine
This is Rietveld 408576698